#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 swagger2
version:              2.8.10
visibility:           public
id:                   swagger2-2.8.10-IxIPb7kKiSIBYrP6Z85Jrj
key:                  swagger2-2.8.10-IxIPb7kKiSIBYrP6Z85Jrj
license:              BSD-3-Clause
copyright:            (c) 2015-2016, GetShopTV
maintainer:           nickolay@getshoptv.com
author:               Nickolay Kudasov
homepage:             https://github.com/GetShopTV/swagger2
synopsis:             Swagger 2.0 data model
description:
    This library is intended to be used for decoding and encoding Swagger 2.0 API
    specifications as well as manipulating them.

    The original Swagger 2.0 specification is available at http://swagger.io/specification/.

category:             Web, Swagger
abi:                  b1fbeba27ac954e7e54b882bae1de2f1
exposed:              True
exposed-modules:
    Data.Swagger Data.Swagger.Declare Data.Swagger.Internal
    Data.Swagger.Internal.AesonUtils Data.Swagger.Internal.ParamSchema
    Data.Swagger.Internal.Schema
    Data.Swagger.Internal.Schema.Validation
    Data.Swagger.Internal.TypeShape Data.Swagger.Internal.Utils
    Data.Swagger.Lens Data.Swagger.Operation Data.Swagger.Optics
    Data.Swagger.ParamSchema Data.Swagger.Schema
    Data.Swagger.Schema.Generator Data.Swagger.Schema.Validation
    Data.Swagger.SchemaOptions

import-dirs:          /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/swagger2-2.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-swagger2
hs-libraries:         HSswagger2-2.8.10-IxIPb7kKiSIBYrP6Z85Jrj
depends:
    QuickCheck-2.15.0.1-KbEu55Yn4v1JAMl6aurZE0
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW
    aeson-pretty-0.8.10-Dq46Vb0SwSV2AiUtN6wUKh base-4.18.2.1
    base-compat-batteries-0.14.1-OXqIAHmAfN5AAF3LucYaY
    bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    generics-sop-0.5.1.4-Jm3azQ1bHSLFwLmIcDOhGt
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    http-media-0.8.1.1-LyJXXt83354JThntJTqBGx
    insert-ordered-containers-0.2.5.3-8Jd9ICZr65OKd3nnw0HEIa
    lens-5.3.4-9D2yk6aQnpf3ebTPLPYG20 mtl-2.3.1
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP
    optics-core-0.4.2-J18Nb2IXjjh13vl8kUWmGX
    optics-th-0.4.1-Kw5XoxV2QI0JRUHojOPxvF
    scientific-0.3.8.1-38VvnYA00bD5k7zFFQre1V template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    uuid-types-1.0.6-AM34zGGUsAQJc9P8ZgCl68
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:   /usr/share/doc/haskell-swagger2/html/swagger2.haddock
haddock-html:         /usr/share/doc/haskell-swagger2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

